﻿using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.VFX;

public class BallGFXParent : MonoBehaviour
{
    public VisualEffect BloodSplosion;


    public GameObject prefabBaby;
    public GameObject prefabChild;
    public GameObject prefabTeenager;
    public GameObject prefabAdult;
    public GameObject prefabAstronaut;

    BallGFX baby;
    BallGFX child;
    BallGFX teenager;
    BallGFX adult;
    BallGFX astronaut;

    BallGFX active = null;
    int activeIndex = -1;

    private void Awake()
    {
        ReInit();
        SwitchTo(0);
    }

    // Update is called once per frame
    void FixedUpdate()
    {
    }

    public void Fire()
    {
        active.Fire();
    }

    internal void SetTarget(Vector2 position)
    {
        active.SetTarget(position);
    }

    public void StopRotation()
    {
        active.StopRotation();
    }

    public void TriggerDeath(Vector3 deathPos)
    {
        active.TriggerDeath(deathPos);

        BloodSplosion.transform.position = deathPos + Vector3.back * 10;
        BloodSplosion.enabled = true;
        BloodSplosion.Play();
    }

    public void SwitchTo(int switchee)
    {
        if (activeIndex == switchee)
            return;

        activeIndex = switchee;

        Vector2 lastTarg = Vector2.zero;
        Vector2 lastPos = Vector2.zero;
        float rotation = 0;
        float rotvel = 0;
        if (active != null)
        {
            lastPos = active.transform.position;
            lastTarg = active.targetJoint.target;
            rotation = active.body.rotation;
            rotvel = active.body.angularVelocity;
            active.gameObject.SetActive(false);

        }

        switch (switchee)
        {
            case 1:
                active = child;
                break;
            case 2:
                active = teenager;
                break;
            case 3:
                active = adult;
                break;
            case 4:
                active = astronaut;
                break;
            default:
                active = baby;
                break;
        }

        active.gameObject.SetActive(true);
        active.transform.position = lastPos;
        active.targetJoint.target = lastTarg;
        active.body.rotation = rotation;
        active.body.angularVelocity = rotvel;
    }

    public void Reset()
    {
        activeIndex = -1;
        ReInit();

        BloodSplosion.enabled = false;
        SwitchTo(0);
        baby.transform.position = Vector3.zero;
    }

    private void ReInit()
    {
        if (baby != null) Destroy(baby.gameObject);
        if (child != null) Destroy(child.gameObject);
        if (teenager != null) Destroy(teenager.gameObject);
        if (adult != null) Destroy(adult.gameObject);
        if (astronaut != null) Destroy(astronaut.gameObject);

        baby = Instantiate(prefabBaby, new Vector3(0, 0, 0), Quaternion.identity).GetComponent<BallGFX>();
        child = Instantiate(prefabChild, new Vector3(0, 0, 0), Quaternion.identity).GetComponent<BallGFX>();
        teenager = Instantiate(prefabTeenager, new Vector3(0, 0, 0), Quaternion.identity).GetComponent<BallGFX>();
        adult = Instantiate(prefabAdult, new Vector3(0, 0, 0), Quaternion.identity).GetComponent<BallGFX>();
        astronaut = Instantiate(prefabAstronaut, new Vector3(0, 0, 0), Quaternion.identity).GetComponent<BallGFX>();

        baby.transform.parent = transform;
        child.transform.parent = transform;
        teenager.transform.parent = transform;
        adult.transform.parent = transform;
        astronaut.transform.parent = transform;
    }
}
