﻿using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Player : MonoBehaviour
{
    public MyCam myCam;

    public GameObject OffScreenIndicator;

    Rigidbody2D RB;

    public Ball ball;
    bool isBallCaught = false;
    bool hasWon = false;


    void Awake()
    {
        RB = GetComponent<Rigidbody2D>();
    }

    void Start()
    {
        
    }

    // Update is called once per frame
    void FixedUpdate()
    {
        float movement = 0.0f;
        if (Input.GetKey(KeyCode.LeftArrow))
        {
            movement -= 1f;
        }
        if (Input.GetKey(KeyCode.RightArrow))
        {
            movement += 1f;
        }


        RB.AddForce(Vector2.right * movement * 20f);
        RB.AddForce(RB.velocity * -0.4f);


        if (Input.GetKey(KeyCode.Space))
        {
            FireBall();
        }
    }

    void Update()
    {
        if (isBallCaught)
            ball.Reset(RB.position);

        if (hasWon)
        {
            ball.transform.position = new Vector3(0f, 200f, 0);
        }

        if (IsOffScreen())
        {
            PlaceOffScreenIndicator();
        }
        else if (OffScreenIndicator.activeSelf)
        {
            OffScreenIndicator.SetActive(false);
        }

        if (ball.isDead || hasWon)
        {
            if (Input.GetKey(KeyCode.R))
            {
                Restart();
            }
        }
        else if (ball.transform.position.y > myCam.transform.position.y + myCam.Size)
        {
            GameHasWon();
        }
    }

    private void GameHasWon()
    {
        hasWon = true;
        UI.inst.HasWon();
    }

    private void Restart()
    {
        hasWon = false;
        Vector3 pos = transform.position;
        pos.x = 0;
        transform.position = pos;
        ball.Restart();
        TargetSpawner.inst.Restart();
        UI.inst.Restart();
    }

    private void PlaceOffScreenIndicator()
    {
        if (!OffScreenIndicator.activeSelf)
            OffScreenIndicator.SetActive(true);

        OffScreenIndicator.transform.localPosition = Vector3.up * (4.3f + myCam.transform.position.y - myCam.Size );
    }

    private bool IsOffScreen()
    {
        return myCam.transform.position.y > 2f;
    }

    private void OnCollisionEnter2D(Collision2D collision)
    {
        if (ball.isDead)
        {
            return;
        }

        if (collision.gameObject.TryGetComponent<Ball>(out _))
        {
            ReceiveBall();
        }
    }


    void FireBall()
    {
        if (!isBallCaught)
            return;

        Audio.inst.PlayWay();

        isBallCaught = false;
        var height = UI.inst.GetHeightOfFire();
        ball.Fire(height, RB);
    }

    void ReceiveBall()
    {
        if (isBallCaught)
            return;

        isBallCaught = true;

        ball.Reset(RB.position);
        Audio.inst.PlayOoh();
    }
}
